#!/bin/bash

dry_run=false

# Ensure OUTPUT_DIR is set
if [ -z "$OUTPUT_DIR" ]; then
    echo "ERROR: OUTPUT_DIR is not set. Please set the OUTPUT_DIR environment variable."
    exit 1
fi

# Parse arguments
while [[ $# -gt 0 ]]; do
    case "$1" in
        --dry)
            dry_run=true
            shift
            ;;
        *)
            echo "Unknown argument: $1"
            echo "Usage: $0 [--mpi] [--i <value>] [--w <value>] [--dry]"
            exit 1
            ;;
    esac
done

# Function to handle actual execution or dry run
run_or_dry() {
    if $dry_run; then
        echo "[DRY RUN] $1"
    else
        echo "Running: $1"  # Print the command that would be executed
        eval "$1"
    fi
}

# ========================
# MPI Benchmark Block
# ========================
echo "Running MPI benchmarks..."
process_counts=(2 4 6 8 10 16 32)

echo "--------------"
echo "MPI benchmarks"
echo "--------------"

# Clear existing log files to avoid appending to old data from previous runs
> mpirun.out
> mpirun.err

for np in "${process_counts[@]}"; do
    cmd="mpirun -np $np python opa_energy_onshore.py --week --read"

    # Add command value to log files with "=" separators
    echo "===============================" >> mpirun.out
    echo "Command: $cmd" >> mpirun.out
    echo "===============================" >> mpirun.out

    echo "===============================" >> mpirun.err
    echo "Command: $cmd" >> mpirun.err
    echo "===============================" >> mpirun.err

    # Execute or dry run
    run_or_dry "$cmd >> mpirun.out 2>> mpirun.err"

    # Remove files after each run
    echo "Cleaning up files in $OUTPUT_DIR..."
    rm "$OUTPUT_DIR"/*.nc
    rm "$OUTPUT_DIR"/*.pkl
done
